@@ -36,7 +36,8 @@ from .recipes_pipe import PipeRecipes
 from .create_sof import SofPipe
 from .init_musepipe import InitMuseParameters
 from . import util_pipe as upipe
-from .util_pipe import filter_list_with_pdict, get_dataset_name
+from .util_pipe import (filter_list_with_pdict, get_dataset_name, 
+                        get_tpl_nexpo, merge_dict, add_string)
 from . import musepipe, prep_recipes_pipe
 from .config_pipe import (default_filter_list, default_PHANGS_filter_list,
                           dict_combined_folders, default_prefix_wcs,
@@ -179,8 +180,8 @@ def get_list_exposures(dataset_path=""):
     list_files = glob.glob(f"{dataset_path}/Object/{prefix_final_cube}*_????.fits")
     list_expos = []
     for name in list_files:
-        [(tpl, lint)] = re.findall(r'\_(\S{19})\_(\d{4}).fits', name)
-        if len(lint) > 0:
+        tpl, lint = get_tpl_nexpo(name)
+        if lint > 0:
             list_expos.append((tpl, np.int(lint)))
 
     # Making it unique and sort
@@ -204,8 +205,9 @@ def get_list_exposures(dataset_path=""):
 
     return dict_expos
 
-def get_list_pixtables(target_path="", list_datasets=None, suffix="",
-                      str_dataset=default_str_dataset, ndigits=default_ndigits):
+def get_list_reduced_pixtables(target_path="", list_datasets=None, 
+                               suffix="", str_dataset=default_str_dataset, 
+                               ndigits=default_ndigits):
     """Provide a list of reduced pixtables
 
     Input
@@ -218,7 +220,8 @@ def get_list_pixtables(target_path="", list_datasets=None, suffix="",
         Additional suffix, if needed, for the names of the PixTables.
     """
     # Getting the pieces of the names to be used for pixtabs
-    pixtable_suffix = prep_recipes_pipe.dict_products_scipost['individual'][0]
+    pixtable_prefix = prep_recipes_pipe.dict_products_scipost['individual'][0]
+    upipe.print_info(f"Will be looking for PIXTABLES with suffix {pixtable_prefix}")
 
     # Initialise the dictionary of pixtabs to be found in each dataset
     dict_pixtables = {}
@@ -234,16 +237,17 @@ def get_list_pixtables(target_path="", list_datasets=None, suffix="",
         path_dataset = joinpath(target_path, get_dataset_name(dataset, str_dataset, ndigits))
         # List existing pixtabs, using the given suffix
         list_pixtabs = glob.glob(path_dataset +
-                                 f"/Object/{pixtable_suffix}{suffix}*fits")
+                                 f"/Object/{pixtable_prefix}{suffix}*fits")
 
         # Reset the needed temporary dictionary
         dict_tpl = {}
         # Loop over the pixtables for that dataset
         for pixtab in list_pixtabs:
             # Split over the PIXTABLE_REDUCED string
-            sl = pixtab.split(pixtable_suffix + "_")
+            sl = pixtab.split(pixtable_prefix + "_")
             # Find the expo number
-            expo = sl[1][-9:-5]
+            nf = len(".fits")
+            expo = sl[1][-int(nf+4):-int(nf)]
             # Find the tpl
             tpl = sl[1].split("_" + expo)[0]
             # If not already there, add it
@@ -269,7 +273,8 @@ class MusePointings(SofPipe, PipeRecipes):
     datasets. This provides a set of rules and methods to access the data and
     process them.
     """
-    def __init__(self, targetname=None, list_pointings=None,
+    def __init__(self, targetname=None, 
+                 list_datasets=None, list_pointings=None,
                  dict_exposures=None,
                  prefix_masked_pixtables="tmask",
                  folder_config="",
@@ -284,8 +289,8 @@ class MusePointings(SofPipe, PipeRecipes):
         Input
         -----
         targetname: string (e.g., 'NGC1208'). default is None.
-        list_pointingw: list of int
-            List of pointing numbers to consider
+        list_datasets: list of int
+            List of datasets numbers to consider
         rc_filename: str
             filename to initialise folders
         cal_filename: str
@@ -360,14 +365,17 @@ class MusePointings(SofPipe, PipeRecipes):
                                               cal_filename=cal_filename,
                                               verbose=verbose)
 
-        # Setting up the relative path for the data, using Galaxy Name + Pointing
+        # Setting up the relative path for the data, using Galaxy Name + Dataset
         self.pipe_params.data = "{0}/{1}/".format(self.targetname,
                                                   self.combined_folder_name)
 
         self.pipe_params.init_default_param(dict_combined_folders)
         self._dict_combined_folders = dict_combined_folders
 
-        self.list_pointings = self._check_pointings_list(list_pointings)
+        # List of pointings to process
+        self.list_pointings = list_pointings
+        # List of datasets to process
+        self.list_datasets = self._check_list_datasets(list_datasets)
         # Setting all the useful paths
         self.set_fullpath_names()
         self.paths.log_filename = joinpath(self.paths.log, log_filename)
@@ -391,7 +399,7 @@ class MusePointings(SofPipe, PipeRecipes):
 
         # Checking input datasets and pixtables
         self._pixtab_in_comb_folder = kwargs.pop("pixtab_in_comb_folder", True)
-        self._get_list_pixtables(dict_exposures)
+        self._get_list_reduced_pixtables(dict_exposures)
 
         # Checking input offset table and corresponding pixtables
         self._check_offset_table(name_offset_table, folder_offset_table)
@@ -457,7 +465,7 @@ class MusePointings(SofPipe, PipeRecipes):
         else:
             return name
 
-    def _get_list_pixtables(self, dict_exposures=None):
+    def _get_list_reduced_pixtables(self, dict_exposures=None):
         """Check if datasets and dictionary are compatible
         """
         # Dictionary of exposures to select per dataset
@@ -471,6 +479,7 @@ class MusePointings(SofPipe, PipeRecipes):
         # Initialise the dictionary of pixtabs to be found in each dataset
         self.dict_pixtabs_in_datasets = {}
         self.dict_allpixtabs_in_datasets = {}
+        self.dict_pixtabs_in_pointings = {}
         # Loop on Datasets
         for dataset in self.list_datasets:
             # get the path
@@ -483,9 +492,13 @@ class MusePointings(SofPipe, PipeRecipes):
                 path_dataset = getattr(self.paths, self.dict_name_datasets[dataset])
                 path_pixtables = path_dataset + self.pipe_params.object
                 dataset_suffix = ""
+
+            # Process the strings to add "_" if needed
+            dataset_suffix = add_string(dataset_suffix)
+            suffix = add_string(self.suffix)
             # List existing pixtabs, using the given suffix
             list_pixtabs = glob.glob(path_pixtables + "{0}{1}{2}*fits".format(
-                                     pixtable_suffix, self.suffix,
+                                     pixtable_suffix, suffix,
                                      dataset_suffix))
 
             # Take (or not) the masked pixtables
@@ -495,7 +508,7 @@ class MusePointings(SofPipe, PipeRecipes):
                 list_masked_pixtabs = glob.glob(path_pixtables +
                                                "{0}{1}{2}*fits".format(
                                                    prefix_to_consider,
-                                                   self.suffix,
+                                                   suffix,
                                                    dataset_suffix))
 
                 # Looping over the existing masked pixtables
@@ -521,13 +534,15 @@ class MusePointings(SofPipe, PipeRecipes):
             self.dict_allpixtabs_in_datasets[dataset] = full_list
 
             # Filter the list with the dataset dictionary if given
-            select_list_pixtabs = filter_list_with_pdict(list_pixtabs,
-                                                         [dataset],
-                                                         self.dict_exposures,
+            select_list_pixtabs, tempp_dict_pixtabs = filter_list_with_pdict(list_pixtabs,
+                                                         list_datasets=[dataset],
+                                                         dict_files=self.dict_exposures,
                                                          verbose=self.verbose)
 
+            self.dict_pixtabs_in_pointings = merge_dict(self.dict_pixtabs_in_pointings, 
+                                                        tempp_dict_pixtabs)
             select_list_pixtabs.sort()
-            self.dict_pixtabs_in_datasets[dataset] = select_list_pixtabs
+            self.dict_pixtabs_in_datasets[dataset] = copy.copy(select_list_pixtabs)
 
     def _read_offset_table(self, name_offset_table=None, folder_offset_table=None):
         """Reading the Offset Table
@@ -739,9 +754,9 @@ class MusePointings(SofPipe, PipeRecipes):
                                         refcube_name=wcs_refcube_name)
 
     def run_combine_all_single_pointings(self, add_suffix="",
-                                      sof_filename='pointings_combine',
-                                      list_pointings=None,
-                                      **kwargs):
+                                         sof_filename='pointings_combine',
+                                         list_pointings=None,
+                                         **kwargs):
         """Run for all pointings individually, provided in the
         list of pointings, by just looping over the pointings.
 
@@ -764,7 +779,7 @@ class MusePointings(SofPipe, PipeRecipes):
         """
         # If list_pointings is None using the initially set up one
         list_pointings = self._check_pointings_list(list_pointings,
-                                               self.list_pointings)
+                                                    self.list_pointings)
 
         # Additional suffix if needed
         for pointing in list_pointings:
@@ -839,13 +854,13 @@ class MusePointings(SofPipe, PipeRecipes):
             List of filter names to be used. 
         """
         # If list_pointings is None using the initially set up one
-        list_pointings = self._check_pointing_list(list_pointings,
-                                               self.list_pointings)
+        list_pointings = self._check_pointings_list(list_pointings,
+                                                    self.list_pointings)
 
         # Additional suffix if needed
         for pointing in list_pointings:
             upipe.print_info("Making WCS Mask for "
-                             "pointing {0:02d}".format(np.int(pointing)))
+                             "Pointing {0:02d}".format(np.int(pointing)))
             _ = self.create_pointing_wcs(pointing=pointing,
                                          filter_list=filter_list, **kwargs)
 
