@@ -43,7 +43,7 @@ import pymusepipe
 from . import util_pipe as upipe
 from .config_pipe import default_wave_wcs, ao_mask_lambda, dict_extra_filters
 from .util_pipe import (filter_list_with_pdict, filter_list_with_suffix_list,\
-                       add_string, default_strds, default_nds)
+                       add_string, default_str_dataset, default_ndigits)
 from .cube_convolve import cube_kernel, cube_convolve
 
 def get_sky_spectrum(specname) :
@@ -321,8 +321,8 @@ class MuseCubeMosaic(CubeMosaic):
         # Attach the other properties to the list of cubes (e.g. PSF)
         self.list_cubes = []
         # Names for the OBs
-        strds = kwargs.pop("strds", default_strds)
-        nds = kwargs.pop("nds", default_nds)
+        str_dataset = kwargs.pop("str_dataset", default_str_dataset)
+        ndigits = kwargs.pop("ndigits", default_ndigits)
         for name in list_cubes:
             self.list_cubes.append(BasicFile(name))
             if len(self.dict_psf) > 0:
@@ -330,7 +330,7 @@ class MuseCubeMosaic(CubeMosaic):
                 for key in self.dict_psf:
                     if found:
                         break
-                    keyword = f"{self.prefix_cubes}_{get_obname(np.int(key), strds, nds)}"
+                    keyword = f"{self.prefix_cubes}_{get_obname(int(key), str_dataset, ndigits)}"
                     if keyword in name:
                         psf = self.dict_psf[key]
                         self.list_cubes[-1].psf = BasicPSF(psf_array=psf)
