@@ -292,12 +292,13 @@ class MusePipeSample(object):
         self.pipes_mosaic = {}
         for targetname in self.targetnames:
             subfolder = self.sample[targetname][0]
-            lpoints = self.sample[targetname][1]
+            ldatasets = self.sample[targetname][1]
+            # Finding out which datasets should be included
             list_datasets = []
-            for lp in lpoints:
-                if lpoints[lp] == 1:
-                    list_datasets.append(lp)
-            # Defining the MusePipe for that target
+            for lds in ldatasets:
+                if ldatasets[lds] == 1:
+                    list_datasets.append(lds)
+            # Defining the MusePipe for that target - which datasets
             self.targets[targetname] = MusePipeTarget(targetname=targetname,
                                                       subfolder=subfolder,
                                                       list_datasets=list_datasets)
@@ -329,7 +330,7 @@ class MusePipeSample(object):
             if self.init_pipes:
                 self.set_pipe_target(targetname, **kwargs_init)
 
-    def _check_datasets_list(self, targetname, list_datasets):
+    def _check_list_datasets(self, targetname, list_datasets):
         """Check if dataset is in the list of datasets
         Returns the list of datasets if ok. If not, return an empty list
 
@@ -407,7 +408,7 @@ class MusePipeSample(object):
         upipe.print_info("=== Initialising MusePipe for Target {name} ===".format(name=targetname))
 
         # Check if datasets are valid
-        list_datasets = self._check_datasets_list(targetname, list_datasets)
+        list_datasets = self._check_list_datasets(targetname, list_datasets)
         if len(list_datasets) == 0:
             return
 
@@ -657,7 +658,7 @@ class MusePipeSample(object):
 
         """
         # Check if datasets are valid
-        list_datasets = self._check_datasets_list(targetname, list_datasets)
+        list_datasets = self._check_list_datasets(targetname, list_datasets)
         upipe.print_info(f"List of datasets to be reduced: {list_datasets}")
         if len(list_datasets) == 0:
             return
@@ -735,7 +736,7 @@ class MusePipeSample(object):
                 first_recipe=recipe_name, last_recipe=recipe_name, **kwargs)
 
         # Check if datasets are valid
-        list_datasets = self._check_datasets_list(targetname, list_datasets)
+        list_datasets = self._check_list_datasets(targetname, list_datasets)
         if len(list_datasets) == 0:
             return
 
@@ -800,7 +801,7 @@ class MusePipeSample(object):
             self.set_pipe_target(targetname=targetname, list_datasets=list_datasets, **kwargs)
 
         # Check if datasets are valid
-        list_datasets = self._check_datasets_list(targetname, list_datasets)
+        list_datasets = self._list_datasets(targetname, list_datasets)
         if len(list_datasets) == 0:
             return
 
@@ -834,7 +835,7 @@ class MusePipeSample(object):
                                  list_datasets=list_datasets, **kwargs)
 
         # Check if datasets are valid
-        list_datasets = self._check_datasets_list(targetname, list_datasets)
+        list_datasets = self._check_list_datasets(targetname, list_datasets)
 
         if len(list_datasets) == 0:
             return
@@ -1047,7 +1048,7 @@ class MusePipeSample(object):
                                          suffix=suffixout,
                                          folder=folder_cubes)
 
-    def init_combine(self, targetname=None, list_pointings=None,
+    def init_combine(self, targetname=None, list_pointings=None, list_datasets=None,
                      folder_offset_table=None, name_offset_table=None,
                      **kwargs):
         """Prepare the combination of targets
@@ -1064,6 +1065,7 @@ class MusePipeSample(object):
         log_filename = kwargs.pop("log_filename", "{0}_combine_{1}.log".format(targetname, version_pack))
         self.pipes_combine[targetname] = MusePointings(targetname=targetname,
                                                     list_pointings=list_pointings,
+                                                    list_datasets=list_datasets,
                                                     rc_filename=self.targets[targetname].rc_filename,
                                                     cal_filename=self.targets[targetname].cal_filename,
                                                     folder_config=self.targets[targetname].folder_config,
