@@ -14,6 +14,7 @@ import time
 from os.path import join as joinpath
 import copy
 from collections import OrderedDict
+import re
 
 # Numpy
 import numpy as np
@@ -186,6 +187,29 @@ def add_string(text, word="_", loc=0):
 
     return text
 
+def get_tpl_nexpo(filename):
+    """Get the tpl and nexpo from a filename assuming it is at the end
+    of the filename
+
+    Input
+    -----
+    filename: str
+       Input filename
+
+    Returns
+    -------
+    tpl, nexpo: str, int
+    """
+    basestr, ext = os.path.splitext(filename)
+    try:
+        [(tpl, nexpo)] = re.findall(r'\_(\S{19})\_(\d{4})', basestr)
+        if len(nexpo) > 0:
+            return tpl, int(nexpo)
+        else:
+            return "", -1
+    except ValueError:
+        return "", -1
+
 def get_dataset_name(dataset=1, str_dataset=default_str_dataset, ndigits=default_ndigits):
     """Formatting for the dataset/pointing names using the number and
     the number of digits and prefix string
@@ -249,6 +273,27 @@ class TimeStampDict(OrderedDict):
         """
         _ = self.pop(tstamp)
 
+def merge_dict(dict1, dict2):
+    """Merging two dictionaries by appending
+    keys which are duplicated
+
+    Input
+    -----
+    dict1: dict
+    dict2: dict
+
+    Returns
+    -------
+    dict1 : dict
+        merged dictionary
+    """
+    for key, value in dict2.items():
+        if key in dict1:
+            dict1[key].extend(value)
+        else:
+            dict1[key] = value
+    return dict1
+
 def create_time_name() :
     """Create a time-link name for file saving purposes
 
@@ -657,16 +702,27 @@ def rotate_cube_wcs(cube_name, cube_folder="", outwcs_folder=None, rotangle=0.,
     else:
         name, extension = os.path.splitext(cube_name)
         if out_suffix != "":
-            out_suffix = "_{}".format(out_suffix)
+            out_suffix = add_string(out_suffix)
         out_name = "{0}{1}{2}".format(name, out_suffix, extension)
 
     # write output
     final_rot_cube.write(joinpath(outwcs_folder, out_name))
     return outwcs_folder, out_name
 
+
+class ExposureInfo(object):
+    def __init__(self, targername, dataset, tpl, nexpo):
+        """A dummy class to just store temporarily
+        the various basic info about a Muse exposure
+        """
+        self.targetname = targetname
+        self.dataset = dataset
+        self.tpl = tpl
+        self.nexpo = nexpo
+
+
 def filter_list_with_pdict(input_list, list_datasets=None,
-                           dict_files=None,
-                           verbose=True):
+                           dict_files=None, verbose=True):
     """Filter out exposures (pixtab or cube namelist) using a dictionary which
     has a list of datasets and for each dataset a list of exposure number.
 
@@ -675,51 +731,94 @@ def filter_list_with_pdict(input_list, list_datasets=None,
         dict_files (dict):  dictionary used to filter
 
     Returns:
-        selected_list: selected list of files
+        selected_filename_list: selected list of files
+        exposure_list_per_pointing: selected list of files for each pointing
 
     """
     nfiles_input_list = len(input_list)
     if dict_files is None:
-          selected_list = input_list
+        # Returning the default input list
+        selected_filename_list = input_list
+        # Just one dummy pointing with all files
+        dict_exposures_per_pointing = {0: input_list}
+        # Building the dummy list of tpl and nexpo for
+        # this input list, decrypting with get_tpl_nexpo
+        list_tplexpo = []
+        for filename in input_list:
+            ftpl, fnexpo = get_tpl_nexpo(filename)
+            list_tplexpo.append([ftpl, fnexpo])
+        dict_tplexpo_per_pointing = {0: list_tplexpo}
 
     # Otherwise use the ones which are given via their expo numbers
     else:
-        selected_list = []
+        selected_filename_list = []
+        dict_exposures_per_pointing = {}
+        dict_tplexpo_per_pointing = {}
         # this is the list of exposures to consider
 
         if list_datasets is None:
             list_datasets = dict_files.keys()
         elif not isinstance(list_datasets, list):
             upipe.print_error("Cannot recognise input dataset(s)")
-            return selected_list
-
-        for dataset in list_datasets:
-            if dataset not in dict_files:
-                upipe.print_warning("Dataset {} not in dictionary "
-                                    "- skipping".format(dataset))
-            else:
-                list_expo = dict_files[dataset]
-                # We loop on that list
-                for expotuple in list_expo:
-                    tpl, nexpo = expotuple[0], expotuple[1]
-                    for expo in nexpo:
-                        # Check whether this exists in the our cube list
-                        suffix_expo = "_{0:04d}".format(np.int(expo))
-                        for filename in input_list:
-                            if (suffix_expo in filename) and (tpl in filename):
-                                # We select the file
-                                selected_list.append(filename)
-                                # And remove it from the list
-                                input_list.remove(filename)
-                                # We break out of the cube for loop
+        else:
+            for dataset in list_datasets:
+                if dataset not in dict_files:
+                    upipe.print_warning("Dataset {} not in dictionary "
+                                        "- skipping".format(dataset))
+                else:
+                    list_tpltuple = dict_files[dataset]
+                    # We loop on that list which should contain 
+                    # the list of tpl associated
+                    # with a list of exposure numbers
+                    for expotuple in list_tpltuple:
+                        # We get the tpl, and then the list of expo numbers
+                        tpl, list_expo = expotuple[0], expotuple[1]
+                        # For each list of expo numbers, check 
+                        # if this is just a number
+                        # or also a pointing association
+                        for expo in list_expo:
+                            # By default we assign the dataset as 
+                            # pointing number
+                            if type(expo) in [str, int]:
+                                nexpo = int(expo)
+                                pointing = int(dataset)
+                            elif len(expo) == 2:
+                                nexpo = int(expo[0])
+                                pointing = int(expo[1])
+                            else:
+                                upipe.print_warning(f"Dictionary entry {expotuple} ignored")
                                 break
 
+                            # Check whether this exists in the our cube list
+#                            suffix_expo = "_{0:04d}".format(nexpo)
+                            for filename in input_list:
+                                ftpl, fnexpo = get_tpl_nexpo(filename)
+#                                if (suffix_expo in filename) and (tpl in filename):
+                                if (nexpo == fnexpo) & (ftpl == tpl):
+                                    # We select the file
+                                    selected_filename_list.append(filename)
+                                    if pointing not in dict_exposures_per_pointing:
+                                        dict_exposures_per_pointing[pointing] = []
+                                        dict_tplexpo_per_pointing[pointing] = []
+                                    dict_exposures_per_pointing[pointing].append(filename)
+                                    dict_tplexpo_per_pointing[pointing].append([tpl, nexpo])
+                                    # And remove it from the list
+                                    input_list.remove(filename)
+                                    # We break out of the cube for loop
+                                    break
+
     if verbose:
-        upipe.print_info("Datasets {0} - Selected {1}/{2} files after "
+        upipe.print_info("Datasets {0} - Selected {1}/{2} exposures after "
                          "dictionary filtering".format(list_datasets,
-                                                len(selected_list),
+                                                len(selected_filename_list),
                                                 nfiles_input_list))
-    return selected_list
+
+        for pointing in dict_tplexpo_per_pointing:
+            upipe.print_info(f"Pointing {pointing} - Detected exposures [TPL / NEXPO]:")
+            for tplexpo in dict_tplexpo_per_pointing[pointing]:
+                upipe.print_info(f"     {tplexpo[0]} / {tplexpo[1]}")
+
+    return selected_filename_list, dict_exposures_per_pointing
 
 def filter_list_with_suffix_list(list_names, included_suffix_list=[],
                                  excluded_suffix_list=[], name_list=""):
